import React, { useState, useEffect, useRef } from 'react';
import { ChevronDown } from 'lucide-react';
import Chat from './chat/Chat';
import * as THREE from 'three';

// 定义 props 类型
interface HeroProps {
  showChat: boolean;
  setShowChat: React.Dispatch<React.SetStateAction<boolean>>;
}

export default function Hero({ showChat, setShowChat }: HeroProps) {
  const mountRef = useRef<HTMLDivElement>(null);
  const sceneRef = useRef<{
    scene: THREE.Scene;
    camera: THREE.PerspectiveCamera;
    renderer: THREE.WebGLRenderer;
    geometry: THREE.TorusKnotGeometry;
    material: THREE.ShaderMaterial;
    torusKnot: THREE.Mesh;
    frameId: number;
  } | null>(null);

  useEffect(() => {
    if (!mountRef.current) return;

    // 初始化场景
    const scene = new THREE.Scene();
    const camera = new THREE.PerspectiveCamera(75, window.innerWidth / window.innerHeight, 0.1, 1000);
    const renderer = new THREE.WebGLRenderer({
      alpha: true,
      antialias: true
    });

    renderer.setSize(window.innerWidth, window.innerHeight);
    renderer.setPixelRatio(Math.min(window.devicePixelRatio, 1.5)); // 限制最大像素比
    mountRef.current.appendChild(renderer.domElement);

    // 根据屏幕大小计算几何体尺寸
    const getGeometrySize = () => {
      const isMobile = window.innerWidth < 768;
      return {
        radius: isMobile ? 6 : 10,
        tube: isMobile ? 2 : 3,
        position: isMobile ? 25 : 30
      };
    };

    const sizes = getGeometrySize();
    // 创建环形节几何体
    const geometry = new THREE.TorusKnotGeometry(sizes.radius, sizes.tube, 64, 16);
    const material = new THREE.ShaderMaterial({
      uniforms: {
        time: { value: 0 },
        color: { value: new THREE.Color(0x3b82f6) }
      },
      vertexShader: `
        varying vec2 vUv;
        void main() {
          vUv = uv;
          gl_Position = projectionMatrix * modelViewMatrix * vec4(position, 1.0);
        }
      `,
      fragmentShader: `
        varying vec2 vUv;
        uniform vec3 color;
        uniform float time;
        void main() {
          float intensity = 0.6 + sin(vUv.x * 5.0 + time) * 0.2;
          gl_FragColor = vec4(color * intensity, 0.15);
        }
      `,
      transparent: true,
      wireframe: true
    });

    const torusKnot = new THREE.Mesh(geometry, material);
    scene.add(torusKnot);

    // 添加光源
    const pointLight = new THREE.PointLight(0x3b82f6, 0.5);
    pointLight.position.set(10, 10, 10);
    scene.add(pointLight);

    const ambientLight = new THREE.AmbientLight(0xffffff, 0.3);
    scene.add(ambientLight);

    // 调整相机位置
    camera.position.z = sizes.position;

    // 添加场景雾效
    scene.fog = new THREE.FogExp2(0x000000, 0.02);

    // 动画循环
    let frameId = 0;
    const animate = () => {
      frameId = requestAnimationFrame(animate);
      if (document.hidden) return;

      const time = performance.now() * 0.001;
      material.uniforms.time.value = time;
      
      torusKnot.rotation.x = time * 0.3;
      torusKnot.rotation.y = time * 0.2;
      
      renderer.render(scene, camera);
    };

    // 开始动画
    animate();

    // 响应窗口大小变化
    const handleResize = () => {
      if (!mountRef.current) return;
      
      const width = window.innerWidth;
      const height = window.innerHeight;

      // 更新相机
      camera.aspect = width / height;
      camera.updateProjectionMatrix();

      // 更新渲染器
      renderer.setSize(width, height);
      renderer.setPixelRatio(Math.min(window.devicePixelRatio, 2));

      // 更新几何体大小
      const sizes = getGeometrySize();
      geometry.dispose();
      torusKnot.geometry = new THREE.TorusKnotGeometry(sizes.radius, sizes.tube, 128, 32);
      camera.position.z = sizes.position;
    };

    window.addEventListener('resize', handleResize);

    // 保存场景引用
    sceneRef.current = {
      scene,
      camera,
      renderer,
      geometry,
      material,
      torusKnot,
      frameId
    };

    // 清理函数
    return () => {
      window.removeEventListener('resize', handleResize);
      if (frameId) cancelAnimationFrame(frameId);
      if (mountRef.current) {
        mountRef.current.removeChild(renderer.domElement);
      }
      geometry.dispose();
      material.dispose();
      renderer.dispose();
    };
  }, []);

  // 控制背景滚动
  useEffect(() => {
    if (showChat) {
      document.body.style.overflow = 'hidden';
    } else {
      document.body.style.overflow = 'auto';
    }
    return () => {
      document.body.style.overflow = 'auto';
    };
  }, [showChat]);

  return (
    <div id="首页" className="relative min-h-screen flex items-center justify-center overflow-hidden">
      <div ref={mountRef} className="absolute inset-0 z-0" />
      <div className="absolute inset-0 hero-background"></div>
      
      <div className="relative z-10 max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 w-full">
        <div className="text-center">
          <div className="mb-12">
            <h1 className="text-6xl sm:text-6xl md:text-9xl font-black tracking-normal sm:tracking-widest">
              <span className="text-gradient-quantum font-quantum">QUANTUM</span>
            </h1>
          </div>
          
          <div className="max-w-4xl mx-auto transform transition-transform duration-500">
            <p className="text-3xl md:text-6xl mb-8 text-white/90 font-quantum-sc flex items-center justify-center gap-2">
              超越 <span className="text-gradient infinity-symbol text-5xl md:text-8xl translate-y-1 md:translate-y-2">∞</span> 维度
            </p>
          </div>
          
          <div className="flex justify-center">
            <button 
              onClick={() => setShowChat(true)}
              className="quantum-button w-32 h-32 md:w-36 md:h-36 rounded-full"
              aria-label="打开AI助手对话"
            >
              <div className="quantum-particles">
                {[...Array(5)].map((_, i) => (
                  <div
                    key={i}
                    className="quantum-particle"
                    style={{
                      left: `${Math.random() * 100}%`,
                      top: `${Math.random() * 100}%`,
                      animationDelay: `${Math.random() * 2}s`
                    }}
                  />
                ))}
              </div>
              <div className="energy-ring"></div>
              <div className="quantum-content flex flex-col items-center justify-center h-full">
                <span className="text-lg font-quantum font-semibold text-blue-400 tracking-widest">
                  点击接入
                </span>
                <span className="text-sm text-blue-500/70 mt-1 font-quantum">
                  Q-Mind
                </span>
              </div>
            </button>
          </div>
        </div>
      </div>

      <div className="absolute bottom-12 left-1/2 transform -translate-x-1/2">
        <a 
          href="#关于我们"
          className="group flex flex-col items-center gap-2"
          onClick={(e) => {
            e.preventDefault();
            document.getElementById('关于我们')?.scrollIntoView({ behavior: 'smooth' });
          }}
          aria-label="滚动到关于我们部分"
        >
          <span className="text-white/50 text-sm font-medium tracking-wider group-hover:text-white/70 transition-colors">
            探索更多
          </span>
          <div className="w-10 h-10 sm:w-10 sm:h-10 bg-glass hover:bg-white/10 transition-all duration-300 rounded-full flex items-center justify-center backdrop-blur-lg border border-white/10 shadow-lg">
            <ChevronDown className="w-4 h-4 sm:w-5 sm:h-5 text-blue-400 group-hover:text-white transition-colors duration-300" />
          </div>
        </a>
      </div>

      {showChat && <Chat onClose={() => setShowChat(false)} />}

      {/* 添加结构化数据 */}
      <script type="application/ld+json" dangerouslySetInnerHTML={{
        __html: JSON.stringify({
          "@context": "https://schema.org",
          "@type": "Organization",
          "name": "终极科技",
          "alternateName": "Quantum AI Technology",
          "description": "终极科技是领先的AI与量子计算技术公司，专注于人工智能、量子计算、深度学习等前沿科技研发。",
          "url": "https://zjkjvr.com/",
          "logo": "https://zjkjvr.com/logo.png",
          "sameAs": [
            // "https://www.linkedin.com/company/aimeta",
            // "https://twitter.com/aimeta"
          ]
        })
      }} />
    </div>
  );
}